@@ -16,9 +16,10 @@ import utm
 from aenum import extend_enum
 
 from ._version import __version__
-from .exceptions import SHUserWarning
+from .exceptions import SHUserWarning, deprecated_class
 
 
+@deprecated_class()
 class PackageProps:
     """Class for obtaining package properties. Currently, it supports obtaining package version."""
 
@@ -115,7 +116,7 @@ class CRSMeta(EnumMeta):
         """
         if isinstance(value, dict) and "init" in value:
             value = value["init"]
-        if isinstance(value, pyproj.CRS):
+        if hasattr(value, "to_epsg"):
             if value == CRSMeta._UNSUPPORTED_CRS:
                 message = (
                     "sentinelhub-py supports only WGS 84 coordinate reference system with "
@@ -148,7 +149,7 @@ class CRSMeta(EnumMeta):
                 value = match.group("code")
             if value.upper() == "CRS84":
                 return "4326"
-            return value.lower().strip("epsg: ")
+            return value.lower().replace("epsg:", "").strip()
         return value
 
 
@@ -451,4 +452,4 @@ class SHConstants:
     """
 
     LATEST = "latest"
-    HEADERS = {"User-Agent": f"sentinelhub-py/v{PackageProps.get_version()}"}
+    HEADERS = {"User-Agent": f"sentinelhub-py/v{__version__}"}
